@@ -1,6 +1,8 @@
 #include <config.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
+#include <gio/gdesktopappinfo.h>
+#include "dm-util.h"
 
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -23,44 +25,56 @@ enum {
 
 static gboolean initial_state;
 
+static GDesktopAppInfo *get_desktop_app_info_from_dm (void)
+{
+    DMType dm_type;
+    GDesktopAppInfo *app_info = NULL;
+
+    dm_type = dm_get_type();
+    if (dm_type == DM_TYPE_MDM) {
+        app_info = g_desktop_app_info_new ("mdmsetup.desktop");
+    } else if (dm_type == DM_TYPE_LIGHTDM) {
+        app_info = g_desktop_app_info_new ("lightdm-gtk-greeter-settings.desktop");
+    }
+    return app_info;
+}
+
 static GtkBuilder *
 create_builder (void)
 {
-	GtkBuilder *builder;
-	GError *error = NULL;
-	static const gchar *uifile = UIDIR "/at-enable-dialog.ui";
+    GtkBuilder *builder;
+    GError *error = NULL;
 
-	builder = gtk_builder_new ();
+    builder = gtk_builder_new ();
 
-	if (gtk_builder_add_from_file (builder, uifile, &error)) {
-		GObject *object;
-		gchar *prog;
+    if (gtk_builder_add_from_resource (builder, "/org/mate/mcc/accessibility/at/at-enable-dialog.ui", &error)) {
+        GObject *object;
+        GDesktopAppInfo *app_info = NULL;
 
-		object = gtk_builder_get_object (builder, "at_enable_image");
-		gtk_image_set_from_file (GTK_IMAGE (object),
-					 PIXMAPDIR "/at-startup.png");
+        object = gtk_builder_get_object (builder, "at_enable_image");
+        gtk_image_set_from_file (GTK_IMAGE (object),
+                                 PIXMAPDIR "/at-startup.png");
 
-		object = gtk_builder_get_object (builder,
-						 "at_applications_image");
-		gtk_image_set_from_file (GTK_IMAGE (object),
-					 PIXMAPDIR "/at-support.png");
+        object = gtk_builder_get_object (builder,
+                                         "at_applications_image");
+        gtk_image_set_from_file (GTK_IMAGE (object),
+                                 PIXMAPDIR "/at-support.png");
+        app_info = get_desktop_app_info_from_dm ();
+        if (app_info == NULL) {
+            object = gtk_builder_get_object (builder, "login_button");
+            gtk_widget_hide (GTK_WIDGET (object));
+        } else {
+            g_object_unref (app_info);
+        }
 
-		prog = g_find_program_in_path ("mdmsetup");
-		if (prog == NULL) {
-			object = gtk_builder_get_object (builder,
-							 "login_button");
-			gtk_widget_hide (GTK_WIDGET (object));
-		}
+    } else {
+        g_warning ("Could not load UI: %s", error->message);
+        g_error_free (error);
+        g_object_unref (builder);
+        builder = NULL;
+    }
 
-		g_free (prog);
-	} else {
-		g_warning ("Could not load UI: %s", error->message);
-		g_error_free (error);
-		g_object_unref (builder);
-		builder = NULL;
-	}
-
-	return builder;
+    return builder;
 }
 
 static void
@@ -84,67 +98,70 @@ cb_mouse_preferences (GtkDialog *dialog, gint response_id)
 static void
 cb_login_preferences (GtkDialog *dialog, gint response_id)
 {
-	g_spawn_command_line_async ("mdmsetup", NULL);
+    GDesktopAppInfo *app_info = NULL;
+
+    app_info = get_desktop_app_info_from_dm ();
+
+    if (app_info != NULL) {
+        g_app_info_launch (G_APP_INFO(app_info),  NULL, NULL, NULL);
+        g_object_unref (app_info);
+    }
 }
 
-/* get_session_bus(), get_sm_proxy(), and do_logout() are all
- * based on code from mate-session-save.c from mate-session.
- */
-static DBusGConnection *
-get_session_bus (void)
-{
-        DBusGConnection *bus;
-        GError *error = NULL;
-
-        bus = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
-
-        if (bus == NULL) {
-                g_warning ("Couldn't connect to session bus: %s", error->message);
-                g_error_free (error);
-        }
-
-        return bus;
-}
-
-static DBusGProxy *
+static GDBusProxy *
 get_sm_proxy (void)
 {
-        DBusGConnection *connection;
-        DBusGProxy      *sm_proxy;
+    GError            *error = NULL;
+    static GDBusProxy *proxy = NULL;
 
-        if (!(connection = get_session_bus ()))
-		return NULL;
-
-        sm_proxy = dbus_g_proxy_new_for_name (connection,
-					      GSM_SERVICE_DBUS,
-					      GSM_PATH_DBUS,
-					      GSM_INTERFACE_DBUS);
-
-        return sm_proxy;
+    if (proxy == NULL) {
+        proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
+                                               G_DBUS_PROXY_FLAGS_NONE,
+                                               NULL,
+                                               GSM_SERVICE_DBUS,
+                                               GSM_PATH_DBUS,
+                                               GSM_INTERFACE_DBUS,
+                                               NULL,
+                                               &error);
+        if (proxy == NULL) {
+            g_warning ("Couldn't connect to session bus: %s", error->message);
+            g_error_free (error);
+        }
+    }
+    return proxy;
 }
 
 static gboolean
-do_logout (GError **err)
+do_logout (void)
 {
-        DBusGProxy *sm_proxy;
-        GError     *error;
-        gboolean    res;
+    GDBusProxy *sm_proxy;
+    GError *error = NULL;
+    GVariant *ret;
+    gboolean res = FALSE;
 
-        sm_proxy = get_sm_proxy ();
-        if (sm_proxy == NULL)
-		return FALSE;
+    sm_proxy = get_sm_proxy ();
+    if (sm_proxy == NULL)
+        return FALSE;
 
-        res = dbus_g_proxy_call (sm_proxy,
-                                 "Logout",
-                                 &error,
-                                 G_TYPE_UINT, 0,   /* '0' means 'log out normally' */
-                                 G_TYPE_INVALID,
-                                 G_TYPE_INVALID);
+    ret = g_dbus_proxy_call_sync (sm_proxy,
+                                  "Logout",
+                                  g_variant_new ("(u)", 0),    /* '0' means 'log out normally' */
+                                  G_DBUS_CALL_FLAGS_NONE,
+                                  -1,
+                                  NULL,
+                                  &error);
+    if (ret == NULL) {
+        g_warning ("Could not call Logout by dbus: %s\n", error->message);
+        g_error_free (error);
+    } else {
+        g_variant_unref (ret);
+        res = TRUE;
+    }
 
-        if (sm_proxy)
-                g_object_unref (sm_proxy);
+    if (sm_proxy)
+        g_object_unref (sm_proxy);
 
-	return res;
+    return res;
 }
 
 static void
@@ -158,8 +175,8 @@ cb_dialog_response (GtkDialog *dialog, gint response_id)
 	else {
 	        g_message ("CLOSE AND LOGOUT!");
 
-		if (!do_logout (NULL))
-			gtk_main_quit ();
+		if (!do_logout ())
+                       gtk_main_quit ();
 	}
 }
 
