@@ -36,7 +36,6 @@ static AppearanceData *
 init_appearance_data (int *argc, char ***argv, GOptionContext *context)
 {
   AppearanceData *data = NULL;
-  gchar *uifile;
   GtkBuilder *ui;
   GError *err = NULL;
 
@@ -45,11 +44,8 @@ init_appearance_data (int *argc, char ***argv, GOptionContext *context)
   activate_settings_daemon ();
 
   /* set up the data */
-  uifile = g_build_filename (MATECC_GTKBUILDER_DIR, "appearance.ui",
-                             NULL);
   ui = gtk_builder_new ();
-  gtk_builder_add_from_file (ui, uifile, &err);
-  g_free (uifile);
+  gtk_builder_add_from_resource (ui, "/org/mate/mcc/appearance/data/appearance.ui", &err);
 
   if (err)
     {
@@ -208,6 +204,12 @@ main (int argc, char **argv)
   if (wallpaper_files && !install_filename && !start_page)
     start_page = g_strdup ("background");
 
+  GtkNotebook* nb = GTK_NOTEBOOK(appearance_capplet_get_widget (data, "main_notebook"));
+  gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
+  g_signal_connect (GTK_WIDGET (nb), "scroll-event",
+                    G_CALLBACK (capplet_dialog_page_scroll_event_cb),
+                    GTK_WINDOW (w));
+
   if (start_page != NULL) {
     gchar *page_name;
 
@@ -216,10 +218,8 @@ main (int argc, char **argv)
 
     w = appearance_capplet_get_widget (data, page_name);
     if (w != NULL) {
-      GtkNotebook *nb;
       gint pindex;
 
-      nb = GTK_NOTEBOOK (appearance_capplet_get_widget (data, "main_notebook"));
       pindex = gtk_notebook_page_num (nb, w);
       if (pindex != -1)
         gtk_notebook_set_current_page (nb, pindex);
