@@ -1546,22 +1546,24 @@ MateThemeMetaInfo* mate_theme_meta_info_new(void)
 
 void mate_theme_meta_info_free(MateThemeMetaInfo* meta_theme_info)
 {
-	g_free(meta_theme_info->path);
-	g_free(meta_theme_info->readable_name);
-	g_free(meta_theme_info->name);
-	g_free(meta_theme_info->comment);
-	g_free(meta_theme_info->application_font);
-	g_free(meta_theme_info->documents_font);
-	g_free(meta_theme_info->desktop_font);
-	g_free(meta_theme_info->windowtitle_font);
-	g_free(meta_theme_info->monospace_font);
-	g_free(meta_theme_info->background_image);
-	g_free(meta_theme_info->gtk_theme_name);
-	g_free(meta_theme_info->gtk_color_scheme);
-	g_free(meta_theme_info->icon_theme_name);
-	g_free(meta_theme_info->marco_theme_name);
-	g_free(meta_theme_info->notification_theme_name);
-	g_free(meta_theme_info);
+	g_free (meta_theme_info->application_font);
+	g_free (meta_theme_info->background_image);
+	g_free (meta_theme_info->comment);
+	g_free (meta_theme_info->cursor_theme_name);
+	g_free (meta_theme_info->desktop_font);
+	g_free (meta_theme_info->documents_font);
+	g_free (meta_theme_info->gtk_color_scheme);
+	g_free (meta_theme_info->gtk_theme_name);
+	g_free (meta_theme_info->icon_file);
+	g_free (meta_theme_info->icon_theme_name);
+	g_free (meta_theme_info->marco_theme_name);
+	g_free (meta_theme_info->monospace_font);
+	g_free (meta_theme_info->name);
+	g_free (meta_theme_info->notification_theme_name);
+	g_free (meta_theme_info->path);
+	g_free (meta_theme_info->sound_theme_name);
+	g_free (meta_theme_info->windowtitle_font);
+	g_free (meta_theme_info);
 }
 
 gboolean mate_theme_meta_info_validate(const MateThemeMetaInfo* info, GError** error)
@@ -1763,6 +1765,7 @@ mate_theme_color_scheme_equal (const gchar *s1, const gchar *s2)
 void
 mate_theme_init ()
 {
+  const gchar * const * dirs;
   GFile *top_theme_dir;
   gchar *top_theme_dir_string;
   static gboolean initted = FALSE;
@@ -1783,13 +1786,16 @@ mate_theme_init ()
   theme_hash_by_uri = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
   theme_hash_by_name = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
-  /* Add all the toplevel theme dirs. */
-  /* $datadir/themes */
-  top_theme_dir_string = gtk_rc_get_theme_dir ();
-  top_theme_dir = g_file_new_for_path (top_theme_dir_string);
-  g_free (top_theme_dir_string);
-  add_top_theme_dir_monitor (top_theme_dir, 1, NULL);
-  g_object_unref (top_theme_dir);
+  /* Add all the toplevel theme dirs following the XDG Base Directory Specification */
+  dirs = g_get_system_data_dirs ();
+  if (dirs != NULL)
+    for (; *dirs != NULL; ++dirs) {
+      top_theme_dir_string = g_build_filename (*dirs, "themes", NULL);
+      top_theme_dir = g_file_new_for_path (top_theme_dir_string);
+      g_free (top_theme_dir_string);
+      add_top_theme_dir_monitor (top_theme_dir, 1, NULL);
+      g_object_unref (top_theme_dir);
+    }
 
   /* ~/.themes */
   top_theme_dir_string  = g_build_filename (g_get_home_dir (), ".themes", NULL);
