@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
+#include <cairo-gobject.h>
 
 #include "mate-da-capplet.h"
 #include "capplet-util.h"
@@ -49,12 +50,13 @@ enum {
 	DA_TYPE_WORD,
 	DA_TYPE_SPREADSHEET,
 	DA_TYPE_CALCULATOR,
+	DA_TYPE_MESSENGER,
 	DA_N_COLUMNS
 };
 
 /* For combo box */
 enum {
-	PIXBUF_COL,
+	SURFACE_COL,
 	TEXT_COL,
 	ID_COL,
 	ICONAME_COL,
@@ -72,7 +74,7 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 	if (index < g_list_length(list))
 	{
 		item = (GAppInfo*) g_list_nth_data(list, index);
-	
+
 		switch (type)
 		{
 			case DA_TYPE_WEB_BROWSER:
@@ -88,11 +90,11 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 				g_app_info_set_as_default_for_type(item, "application/x-extension-eml", NULL);
 				g_app_info_set_as_default_for_type(item, "message/rfc822", NULL);
 				break;
-			
+
 			case DA_TYPE_FILE:
 				g_app_info_set_as_default_for_type(item, "inode/directory", NULL);
 				break;
-			
+
 			case DA_TYPE_TEXT:
 				g_app_info_set_as_default_for_type(item, "text/plain", NULL);
 				break;
@@ -104,7 +106,7 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 				g_app_info_set_as_default_for_type(item, "audio/x-vorbis+ogg", NULL);
 				g_app_info_set_as_default_for_type(item, "audio/x-wav", NULL);
 				break;
-				
+
 			case DA_TYPE_VIDEO:
 				g_app_info_set_as_default_for_type(item, "video/mp4", NULL);
 				g_app_info_set_as_default_for_type(item, "video/mpeg", NULL);
@@ -160,6 +162,14 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 				g_settings_set_string (capplet->calculator_settings, CALCULATOR_KEY, g_app_info_get_executable (item));
 				break;
 
+			case DA_TYPE_MESSENGER:
+				g_app_info_set_as_default_for_type(item, "x-scheme-handler/icq", NULL);
+				g_app_info_set_as_default_for_type(item, "x-scheme-handler/irc", NULL);
+				g_app_info_set_as_default_for_type(item, "x-scheme-handler/ircs", NULL);
+				g_app_info_set_as_default_for_type(item, "x-scheme-handler/sip", NULL);
+				g_app_info_set_as_default_for_type(item, "x-scheme-handler/xmpp", NULL);
+				g_settings_set_string (capplet->messenger_settings, MESSENGER_KEY, g_app_info_get_executable (item));
+
 			default:
 				break;
 		}
@@ -189,6 +199,7 @@ close_cb(GtkWidget* window, gint response, MateDACapplet* capplet)
 		set_changed(GTK_COMBO_BOX(capplet->word_combo_box), capplet, capplet->word_editors, DA_TYPE_WORD);
 		set_changed(GTK_COMBO_BOX(capplet->spreadsheet_combo_box), capplet, capplet->spreadsheet_editors, DA_TYPE_SPREADSHEET);
 		set_changed(GTK_COMBO_BOX(capplet->calculator_combo_box), capplet, capplet->calculators, DA_TYPE_CALCULATOR);
+		set_changed(GTK_COMBO_BOX(capplet->messenger_combo_box), capplet, capplet->messengers, DA_TYPE_MESSENGER);
 
 		gtk_widget_destroy(window);
 		gtk_main_quit();
@@ -280,14 +291,21 @@ calculator_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
 	set_changed(combo, capplet, capplet->calculators, DA_TYPE_CALCULATOR);
 }
 
+static void
+messenger_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+{
+        set_changed(combo, capplet, capplet->messengers, DA_TYPE_MESSENGER);
+}
+
 static void
 refresh_combo_box_icons(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list)
 {
 	GtkTreeIter iter;
 	GtkTreeModel* model;
 	gboolean valid;
-	GdkPixbuf* pixbuf;
+	cairo_surface_t *surface;
 	gchar* icon_name;
+	gint scale_factor;
 
 	model = gtk_combo_box_get_model(combo_box);
 
@@ -295,29 +313,31 @@ refresh_combo_box_icons(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_
 		return;
 
 	valid = gtk_tree_model_get_iter_first(model, &iter);
-	
+	scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (combo_box));
+
 	while (valid)
-    {
-		gtk_tree_model_get(model, &iter,
-				          ICONAME_COL, &icon_name,
-				          -1);
+	{
+		gtk_tree_model_get (model, &iter,
+		                    ICONAME_COL, &icon_name,
+		                    -1);
 
-		GtkIconInfo* icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, 22, GTK_ICON_LOOKUP_FORCE_SIZE);
-		pixbuf = gtk_icon_info_load_icon(icon_info, NULL);
+		surface = gtk_icon_theme_load_surface (theme, icon_name,
+		                                       22, scale_factor,
+		                                       NULL,
+		                                       GTK_ICON_LOOKUP_FORCE_SIZE,
+		                                       NULL);
 
-		gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-				PIXBUF_COL, pixbuf,
-				-1);
+		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+		                    SURFACE_COL, surface,
+		                    -1);
 
-		if (pixbuf)
-		{
-			g_object_unref(pixbuf);
-		}
-		
-		g_free(icon_name);
+		if (surface)
+			cairo_surface_destroy (surface);
+
+		g_free (icon_name);
 
 		valid = gtk_tree_model_iter_next(model, &iter);
-    }
+	}
 }
 
 static struct {
@@ -329,7 +349,7 @@ static struct {
 	{"media_player_image", "audio-x-generic"},
 	{"visual_image",       "zoom-best-fit"},
 	{"mobility_image",     "preferences-desktop-accessibility"},
-	{"messenger_image",    "user-idle"},
+	{"messenger_image",    "instant-messaging"},
 	{"filemanager_image",  "file-manager"},
 	{"imageviewer_image",  "image-x-generic"},
 	{"video_image",        "video-x-generic"},
@@ -347,20 +367,25 @@ theme_changed_cb(GtkIconTheme* theme, MateDACapplet* capplet)
 {
 	GObject* icon;
 	gint i;
+	gint scale_factor;
+	cairo_surface_t *surface;
+
+	scale_factor = gtk_widget_get_scale_factor (capplet->window);
 
 	for (i = 0; i < G_N_ELEMENTS(icons); i++)
 	{
 		icon = gtk_builder_get_object(capplet->builder, icons[i].name);
 
-		GtkIconInfo* icon_info = gtk_icon_theme_lookup_icon (theme, icons[i].icon, 32, GTK_ICON_LOOKUP_FORCE_SIZE);
-		GdkPixbuf* pixbuf = gtk_icon_info_load_icon(icon_info, NULL);
+		surface = gtk_icon_theme_load_surface (theme, icons[i].icon,
+		                                       32, scale_factor,
+		                                       NULL,
+		                                       GTK_ICON_LOOKUP_FORCE_SIZE,
+		                                       NULL);
 
-		gtk_image_set_from_pixbuf(GTK_IMAGE(icon), pixbuf);
-		
-		if (pixbuf)
-		{
-			g_object_unref(pixbuf);
-		}
+		gtk_image_set_from_surface (GTK_IMAGE(icon), surface);
+
+		if (surface)
+			cairo_surface_destroy (surface);
 	}
 
 	refresh_combo_box_icons(theme, GTK_COMBO_BOX(capplet->web_combo_box), capplet->web_browsers);
@@ -376,6 +401,7 @@ theme_changed_cb(GtkIconTheme* theme, MateDACapplet* capplet)
 	refresh_combo_box_icons(theme, GTK_COMBO_BOX(capplet->word_combo_box), capplet->word_editors);
 	refresh_combo_box_icons(theme, GTK_COMBO_BOX(capplet->spreadsheet_combo_box), capplet->spreadsheet_editors);
 	refresh_combo_box_icons(theme, GTK_COMBO_BOX(capplet->calculator_combo_box), capplet->calculators);
+        refresh_combo_box_icons(theme, GTK_COMBO_BOX(capplet->messenger_combo_box), capplet->messengers);
 }
 
 static void
@@ -404,8 +430,9 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 	GtkTreeModel* model;
 	GtkCellRenderer* renderer;
 	GtkTreeIter iter;
-	GdkPixbuf* pixbuf;
+	cairo_surface_t *surface;
 	GAppInfo* default_app;
+	gint scale_factor;
 
 	default_app = NULL;
 	if (g_strcmp0(mime, "terminal") == 0)
@@ -468,6 +495,21 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		g_free (default_calculator);
 		g_object_unref (calculator_settings);
 	}
+	else if (g_strcmp0(mime, "messenger") == 0)
+	{
+		GSettings *messenger_settings = g_settings_new (MESSENGER_SCHEMA);
+		gchar *default_messenger = g_settings_get_string (messenger_settings, MESSENGER_KEY);
+		for (entry = app_list; entry != NULL; entry = g_list_next(entry))
+		{
+			GAppInfo* item = (GAppInfo*) entry->data;
+			if (g_strcmp0 (g_app_info_get_executable (item), default_messenger) == 0)
+			{
+				default_app = item;
+			}
+		}
+		g_free (default_messenger);
+		g_object_unref (messenger_settings);
+	}
 	else
 	{
 		default_app = g_app_info_get_default_for_type (mime, FALSE);
@@ -478,17 +520,21 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		theme = gtk_icon_theme_get_default();
 	}
 
-	model = GTK_TREE_MODEL(gtk_list_store_new(4, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING));
+	model = GTK_TREE_MODEL (gtk_list_store_new (4,
+	                                            CAIRO_GOBJECT_TYPE_SURFACE,
+	                                            G_TYPE_STRING,
+	                                            G_TYPE_STRING,
+	                                            G_TYPE_STRING));
 	gtk_combo_box_set_model(combo_box, model);
 
 	renderer = gtk_cell_renderer_pixbuf_new();
 
-	/* Not all cells have a pixbuf, this prevents the combo box to shrink */
+	/* Not all cells have an icon, this prevents the combo box to shrink */
 	gtk_cell_renderer_set_fixed_size(renderer, 22, 22);
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo_box), renderer, FALSE);
-	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo_box), renderer,
-		"pixbuf", PIXBUF_COL,
-		NULL);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), renderer,
+	                                "surface", SURFACE_COL,
+	                                NULL);
 
 	renderer = gtk_cell_renderer_text_new();
 
@@ -497,10 +543,12 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		"text", TEXT_COL,
 		NULL);
 
+	scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (combo_box));
+
 	for (entry = app_list; entry != NULL; entry = g_list_next(entry))
 	{
 		GAppInfo* item = (GAppInfo*) entry->data;
-		
+
 		/* Icon */
 		GIcon* icon = g_app_info_get_icon(item);
 		gchar* icon_name;
@@ -514,31 +562,32 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		} else {
 			icon_name = g_strdup ("binary");
 		}
-		
-		GtkIconInfo* icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, 22, GTK_ICON_LOOKUP_FORCE_SIZE);
-		pixbuf = gtk_icon_info_load_icon(icon_info, NULL);
+
+		surface = gtk_icon_theme_load_surface (theme, icon_name,
+		                                       22, scale_factor,
+		                                       NULL,
+		                                       GTK_ICON_LOOKUP_FORCE_SIZE,
+		                                       NULL);
 
 		gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-			PIXBUF_COL, pixbuf,
-			TEXT_COL, g_app_info_get_display_name(item),
-			ID_COL, g_app_info_get_id(item),
-			ICONAME_COL, icon_name,
-			-1);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		                    SURFACE_COL, surface,
+		                    TEXT_COL, g_app_info_get_display_name(item),
+		                    ID_COL, g_app_info_get_id(item),
+		                    ICONAME_COL, icon_name,
+		                    -1);
+
+		if (surface)
+			cairo_surface_destroy (surface);
 
-		if (pixbuf)
-		{
-			g_object_unref(pixbuf);
-		}
-		
 		/* Set the index for the default app */
 		if (default_app != NULL && g_app_info_equal(item, default_app))
 		{
 			gtk_combo_box_set_active(combo_box, index);
 		}
-		
+
 		g_free(icon_name);
-		
+
 		index++;
 	}
 }
@@ -556,6 +605,23 @@ fill_list_from_desktop_file (GList* app_list, const gchar *desktop_id)
 	return list;
 }
 
+static gint
+compare_apps (gconstpointer a, gconstpointer b)
+{
+	GAppInfo *app_info_1, *app_info_2;
+	gchar *app_dpy_name_1, *app_dpy_name_2;
+	gint ret;
+
+	app_info_1 = G_APP_INFO (a);
+	app_info_2 = G_APP_INFO (b);
+	app_dpy_name_1 = g_utf8_casefold (g_app_info_get_display_name (app_info_1), -1);
+	app_dpy_name_2 = g_utf8_casefold (g_app_info_get_display_name (app_info_2), -1);
+	ret = g_strcmp0 (app_dpy_name_1, app_dpy_name_2);
+	g_free (app_dpy_name_1);
+	g_free (app_dpy_name_2);
+	return ret;
+}
+
 static void
 show_dialog(MateDACapplet* capplet, const gchar* start_page)
 {
@@ -566,14 +632,7 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 
 	capplet->builder = builder = gtk_builder_new ();
 
-	if (g_file_test(MATECC_UI_DIR "/mate-default-applications-properties.ui", G_FILE_TEST_EXISTS) != FALSE)
-	{
-		builder_result = gtk_builder_add_from_file(builder, MATECC_UI_DIR "/mate-default-applications-properties.ui", NULL);
-	}
-	else
-	{
-		builder_result = gtk_builder_add_from_file(builder, "./mate-default-applications-properties.ui", NULL);
-	}
+	builder_result = gtk_builder_add_from_resource (builder, "/org/mate/mcc/da/mate-default-applications-properties.ui", NULL);
 
 	if (builder_result == 0)
 	{
@@ -605,6 +664,7 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 	capplet->word_combo_box = get_widget("word_combobox");
 	capplet->spreadsheet_combo_box = get_widget("spreadsheet_combobox");
 	capplet->calculator_combo_box = get_widget("calculator_combobox");
+        capplet->messenger_combo_box = get_widget("messenger_combobox");
 
 	capplet->visual_startup_checkbutton = get_widget("visual_start_checkbutton");
 	capplet->mobility_startup_checkbutton = get_widget("mobility_start_checkbutton");
@@ -625,7 +685,13 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 	capplet->spreadsheet_editors = g_app_info_get_all_for_type("application/vnd.ms-excel");
 
 	capplet->visual_ats = NULL;
-	capplet->visual_ats = fill_list_from_desktop_file (capplet->visual_ats, APPLICATIONSDIR "/orca.desktop");
+        const gchar *const *sys_config_dirs = g_get_system_config_dirs();
+	for (const gchar* c = *sys_config_dirs; c; c=*++sys_config_dirs)
+        {
+		gchar* path = g_strconcat (c, "/autostart/orca-autostart.desktop", NULL);
+		capplet->visual_ats = fill_list_from_desktop_file (capplet->visual_ats, path);
+		g_free (path);
+	}
 	capplet->visual_ats = g_list_reverse (capplet->visual_ats);
 
 	capplet->mobility_ats = NULL;
@@ -666,6 +732,24 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 	}
 	capplet->calculators = g_list_reverse (capplet->calculators);
 
+	/* Messenger havent mime types, so check in .desktop files for
+	   Categories=InstantMessaging */
+	capplet->messengers = g_app_info_get_all_for_type ("x-scheme-handler/irc");
+	all_apps = g_app_info_get_all();
+	for (entry = all_apps; entry != NULL; entry = g_list_next(entry))
+	{
+		if (capplet->messengers && g_list_index (capplet->messengers, entry) != -1)
+			continue;
+
+		GDesktopAppInfo* item = (GDesktopAppInfo*) entry->data;
+		if (g_desktop_app_info_get_categories (item) != NULL &&
+			g_strrstr (g_desktop_app_info_get_categories (item), "InstantMessaging"))
+		{
+			capplet->messengers = g_list_prepend (capplet->messengers, item);
+		}
+	}
+	capplet->messengers = g_list_sort (capplet->messengers, compare_apps);
+
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->web_combo_box), capplet->web_browsers, "x-scheme-handler/http");
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->mail_combo_box), capplet->mail_readers, "x-scheme-handler/mailto");
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->term_combo_box), capplet->terminals, "terminal");
@@ -680,6 +764,7 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->word_combo_box), capplet->word_editors, "application/vnd.oasis.opendocument.text");
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->spreadsheet_combo_box), capplet->spreadsheet_editors, "application/vnd.oasis.opendocument.spreadsheet");
 	fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->calculator_combo_box), capplet->calculators, "calculator");
+        fill_combo_box(capplet->icon_theme, GTK_COMBO_BOX(capplet->messenger_combo_box), capplet->messengers, "messenger");
 
 	g_signal_connect(capplet->web_combo_box, "changed", G_CALLBACK(web_combo_changed_cb), capplet);
 	g_signal_connect(capplet->mail_combo_box, "changed", G_CALLBACK(mail_combo_changed_cb), capplet);
@@ -695,12 +780,19 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 	g_signal_connect(capplet->word_combo_box, "changed", G_CALLBACK(word_combo_changed_cb), capplet);
 	g_signal_connect(capplet->spreadsheet_combo_box, "changed", G_CALLBACK(spreadsheet_combo_changed_cb), capplet);
 	g_signal_connect(capplet->calculator_combo_box, "changed", G_CALLBACK(calculator_combo_changed_cb), capplet);
+        g_signal_connect(capplet->messenger_combo_box, "changed", G_CALLBACK(messenger_combo_changed_cb), capplet);
 
 	g_settings_bind (capplet->mobility_settings, MOBILITY_STARTUP_KEY, capplet->mobility_startup_checkbutton, "active", G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind (capplet->visual_settings, VISUAL_STARTUP_KEY, capplet->visual_startup_checkbutton, "active", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind (capplet->visual_startup_settings, VISUAL_STARTUP_KEY, capplet->visual_startup_checkbutton, "active", G_SETTINGS_BIND_DEFAULT);
 
 	gtk_window_set_icon_name(GTK_WINDOW (capplet->window), "preferences-desktop-default-applications");
 
+        GtkNotebook* nb = GTK_NOTEBOOK(get_widget("preferred_apps_notebook"));
+        gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
+        g_signal_connect (GTK_WIDGET (nb), "scroll-event",
+                          G_CALLBACK (capplet_dialog_page_scroll_event_cb),
+                          GTK_WINDOW (capplet->window));
+
 	if (start_page != NULL)
 	{
 		gchar* page_name;
@@ -712,12 +804,10 @@ show_dialog(MateDACapplet* capplet, const gchar* start_page)
 
 		if (w != NULL)
 		{
-			GtkNotebook* nb;
 			gint pindex;
 
-			nb = GTK_NOTEBOOK(get_widget("preferred_apps_notebook"));
 			pindex = gtk_notebook_page_num(nb, w);
-			
+
 			if (pindex != -1)
 			{
 				gtk_notebook_set_current_page(nb, pindex);
@@ -761,7 +851,9 @@ main(int argc, char** argv)
 	capplet->terminal_settings = g_settings_new (TERMINAL_SCHEMA);
 	capplet->mobility_settings = g_settings_new (MOBILITY_SCHEMA);
 	capplet->visual_settings = g_settings_new (VISUAL_SCHEMA);
+	capplet->visual_startup_settings = g_settings_new (VISUAL_STARTUP_SCHEMA);
 	capplet->calculator_settings = g_settings_new (CALCULATOR_SCHEMA);
+	capplet->messenger_settings = g_settings_new (MESSENGER_SCHEMA);
 
 	show_dialog(capplet, start_page);
 	g_free(start_page);
@@ -771,7 +863,9 @@ main(int argc, char** argv)
 	g_object_unref (capplet->terminal_settings);
 	g_object_unref (capplet->mobility_settings);
 	g_object_unref (capplet->visual_settings);
+	g_object_unref (capplet->visual_startup_settings);
 	g_object_unref (capplet->calculator_settings);
+	g_object_unref (capplet->messenger_settings);
 
 	return 0;
 }
