@@ -33,7 +33,6 @@
 
 #include "capplet-util.h"
 #include "activate-settings-daemon.h"
-#include "capplet-stock-icons.h"
 
 #include "mate-keyboard-properties-a11y.h"
 #include "mate-keyboard-properties-xkb.h"
@@ -58,10 +57,9 @@ create_dialog (void)
 	GtkSizeGroup *size_group;
 	GtkWidget *image;
 	GError *error = NULL;
-	static const gchar *uifile = MATECC_UI_DIR "/mate-keyboard-properties-dialog.ui";
 
 	dialog = gtk_builder_new ();
-	if (gtk_builder_add_from_file (dialog, uifile, &error) == 0) {
+	if (gtk_builder_add_from_resource (dialog, "/org/mate/mcc/keyboard/mate-keyboard-properties-dialog.ui", &error) == 0) {
 		g_warning ("Could not load UI: %s", error->message);
 		g_error_free (error);
 		g_object_unref (dialog);
@@ -244,17 +242,18 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 
 	setup_dialog (dialog);
+
+        GtkNotebook* nb = GTK_NOTEBOOK (WID ("keyboard_notebook"));
+        gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
+        g_signal_connect (GTK_WIDGET (nb), "scroll-event",
+                          G_CALLBACK (capplet_dialog_page_scroll_event_cb),
+                          GTK_WINDOW (WID ("keyboard_dialog")));
+
 	if (switch_to_typing_break_page) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK
-					       (WID
-						("keyboard_notebook")),
-					       4);
+		gtk_notebook_set_current_page (nb, 4);
 	}
 	else if (switch_to_a11y_page) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK
-					       (WID
-						("keyboard_notebook")),
-					       2);
+		gtk_notebook_set_current_page (nb, 2);
 
 	}
 
