@@ -2,16 +2,16 @@
  * Copyright (c) 2011, 2012 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by 
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public 
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License 
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
@@ -24,8 +24,6 @@
 #include <math.h>
 #include <glib/gi18n.h>
 
-G_DEFINE_TYPE (GdMainToolbar, gd_main_toolbar, GTK_TYPE_TOOLBAR)
-
 typedef enum {
   CHILD_NORMAL = 0,
   CHILD_TOGGLE = 1,
@@ -62,6 +60,8 @@ enum {
         PROP_SHOW_MODES,
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GdMainToolbar, gd_main_toolbar, GTK_TYPE_TOOLBAR)
+
 static void
 gd_main_toolbar_dispose (GObject *obj)
 {
@@ -328,7 +328,7 @@ gd_main_toolbar_constructed (GObject *obj)
 static void
 gd_main_toolbar_init (GdMainToolbar *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GD_TYPE_MAIN_TOOLBAR, GdMainToolbarPrivate);
+  self->priv = gd_main_toolbar_get_instance_private (self);
 }
 
 static void
@@ -349,8 +349,6 @@ gd_main_toolbar_class_init (GdMainToolbarClass *klass)
                                                          "Show Modes",
                                                          FALSE,
                                                          G_PARAM_READWRITE));
-
-  g_type_class_add_private (klass, sizeof (GdMainToolbarPrivate));
 }
 
 void
@@ -365,7 +363,7 @@ gd_main_toolbar_clear (GdMainToolbar *self)
                          (GtkCallback) gtk_widget_destroy, self);
   gtk_container_foreach (GTK_CONTAINER (self->priv->modes_box),
                          (GtkCallback) gtk_widget_destroy, self);
-  gtk_container_foreach (GTK_CONTAINER (self->priv->right_grid), 
+  gtk_container_foreach (GTK_CONTAINER (self->priv->right_grid),
                          (GtkCallback) gtk_widget_destroy, self);
 }
 
